{% extends "registration/base.html" %}
{% load i18n %}

{% block registration_content %}{{ block.super }}
    <h3>{% blocktrans %}You have completed your registration{% endblocktrans %}</h3>
    <p>{% blocktrans %}An activation email has been sent to your email account, you must use the activation link in this email to finally activate your account{% endblocktrans %}.</p>
{% endblock %}