{% extends "skeleton.html" %}
{% load autobreadcrumb %}

{% block head_title %}{% current_title_from_breadcrumbs %}{% endblock %}

{% block content %}
    {% block registration_content %}<h2>{% current_title_from_breadcrumbs %}</h2>{% endblock %}
{% endblock %}
