{% extends "registration/base.html" %}
{% load i18n %}

{% block registration_content %}{{ block.super }}
    <h3>{% blocktrans %}Registration blocked{% endblocktrans %}</h3>
    <p>{% blocktrans %}This site does not accepts any registration{% endblocktrans %}.</p>
{% endblock %}