{% extends "registration/base.html" %}
{% load i18n %}

{% block registration_content %}{{ block.super }}
    <h3>{% blocktrans %}The given activation key is not valid{% endblocktrans %}</h3>
    <p>{% blocktrans %}We can't process your activation{% endblocktrans %}.</p>
{% endblock %}