{% extends "registration/base.html" %}
{% load i18n %}

{% block registration_content %}
    {{ block.super }}
    <div class="row">
        <div class="six columns centered">
            <p>{% trans "Email with password reset instructions has been sent." %}</p>
        </div>
    </div>
{% endblock %}
