{% extends "registration/base.html" %}
{% load i18n %}

{% block registration_content %}{{ block.super }}
    <h3>{% blocktrans %}You are not allowed to complete this registration{% endblocktrans %}</h3>
    <p>{% blocktrans %}This is probably because it has allready be activated or the delay to activate your account has expired{% endblocktrans %}.</p>
{% endblock %}